<?php
/**
 * WC_Predictive_Search_Settings Class
 *
 * Class Function into WooCommerce plugin
 *
 * Table Of Contents
 *
 * custom_types()
 * set_setting()
 * __construct()
 * on_add_tab()
 * predictive_search_global_start()
 * predictive_search_global_end()
 * predictive_search_results_end()
 * predictive_search_excludes_end()
 * settings_tab_action()
 * add_settings_fields()
 * get_tab_in_view()
 * init_form_fields()
 * save_settings()
 * setting()
 * predictive_search_code_start()
 * wc_predictive_search_multi_select()
 */
class WC_Predictive_Search_Settings 
{
	public function custom_types() {
		$custom_type = array('wc_predictive_search_multi_select');
		
		return $custom_type;
	}
	
	public function set_setting($reset=false){
		if ( get_option('woocommerce_search_text_lenght') <= 0 || $reset ) {
			update_option('woocommerce_search_text_lenght','100');
		}
		if ( get_option('woocommerce_search_result_items') <= 0 || $reset ) {
			update_option('woocommerce_search_result_items','10');
		}
		if ( get_option('woocommerce_search_sku_enable') == '' || $reset ) {
			update_option('woocommerce_search_sku_enable', 'yes');
		}
		if ( get_option('woocommerce_search_price_enable') == '' || $reset ) {
			update_option('woocommerce_search_price_enable', 'yes');
		}
		if ( get_option('woocommerce_search_addtocart_enable') == '' || $reset ) {
			update_option('woocommerce_search_addtocart_enable', 'yes');
		}
		if ( get_option('woocommerce_search_categories_enable') == ''  || $reset ) {
			update_option('woocommerce_search_categories_enable', 'yes');
		}
		if ( get_option('woocommerce_search_tags_enable') == '' || $reset ) {
			update_option('woocommerce_search_tags_enable', 'yes');
		}
		if ( get_option('woocommerce_search_product_items') == '' || $reset ) {
			update_option('woocommerce_search_product_items', '6');
		}
		if ( get_option('woocommerce_search_show_price') == '' || $reset ) {
			update_option('woocommerce_search_show_price', 'yes');
		}
		if ( get_option('woocommerce_search_character_max') == '' || $reset ) {
			update_option('woocommerce_search_character_max', '100');
		}
		if ( get_option('woocommerce_search_global_search') == '' || $reset ) {
			update_option('woocommerce_search_global_search', 'yes');
		}
		
		if ( get_option('woocommerce_search_focus_enable') == '' || $reset ) {
			update_option('woocommerce_search_focus_enable', 'yes');
		}
		if ( get_option('woocommerce_search_focus_plugin') == '' || $reset ) {
			update_option('woocommerce_search_focus_plugin', 'none');
		}
		if ( get_option('woocommerce_search_clean_on_deletion') == '' || $reset ) {
			update_option('woocommerce_search_clean_on_deletion', 0);
		}
		if ( $reset ) {
			update_option('woocommerce_search_box_text', '');
		}
	}
	
	public function __construct() {
   		$this->current_tab = ( isset($_GET['tab']) ) ? $_GET['tab'] : 'general';
    	$this->settings_tabs = array(
        	'ps_settings' => __('Predictive Search', 'woops')
        );
        add_action('woocommerce_settings_tabs', array(&$this, 'on_add_tab'), 10);
		
		// add custom type to woocommerce fields
		foreach ($this->custom_types() as $custom_type) {
			add_action('woocommerce_admin_field_'.$custom_type, array(&$this, $custom_type) );
		}

        // Run these actions when generating the settings tabs.
        foreach ( $this->settings_tabs as $name => $label ) {
        	add_action('woocommerce_settings_tabs_' . $name, array(&$this, 'settings_tab_action'), 10);
			if (get_option('a3rev_woo_predictivesearch_just_confirm') == 1) {
          		update_option('a3rev_woo_predictivesearch_just_confirm', 0);
			} else {
				add_action('woocommerce_update_options_' . $name, array(&$this, 'save_settings'), 10);
			}
        }
		
		add_action( 'woocommerce_settings_predictive_search_searchbox_text_start', array(&$this, 'predictive_search_searchbox_text_start') );
		add_action( 'woocommerce_settings_predictive_search_global_start', array(&$this, 'predictive_search_global_start') );
		add_action( 'woocommerce_settings_predictive_search_global_end_after', array(&$this, 'predictive_search_global_end') );
		add_action( 'woocommerce_settings_predictive_search_results_end_after', array(&$this, 'predictive_search_results_end') );
		add_action( 'woocommerce_settings_predictive_search_excludes_end_after', array(&$this, 'predictive_search_excludes_end') );
		
		add_action( 'woocommerce_settings_predictive_search_code_start', array(&$this, 'predictive_search_code_start') );

        // Add the settings fields to each tab.
        add_action('woocommerce_ps_settings', array(&$this, 'add_settings_fields'), 10);
				
	}

    /*
    * Admin Functions
    */

    /* ----------------------------------------------------------------------------------- */
    /* Admin Tabs */
    /* ----------------------------------------------------------------------------------- */
	public function on_add_tab() {
    	foreach ( $this->settings_tabs as $name => $label ) :
        	$class = 'nav-tab';
      		if ( $this->current_tab == $name )
            	$class .= ' nav-tab-active';
      		echo '<a href="' . admin_url('admin.php?page=woocommerce_settings&tab=' . $name, 'relative' ) . '" class="' . $class . '">' . $label . '</a>';
     	endforeach;
	}
	
	public function predictive_search_searchbox_text_start() {
		if ( class_exists('SitePress') ) {
			$woocommerce_search_box_text = get_option('woocommerce_search_box_text', array() );
			if ( !is_array( $woocommerce_search_box_text) ) $woocommerce_search_box_text = array();
			
			global $sitepress;
			$active_languages = $sitepress->get_active_languages();
			if ( is_array($active_languages)  && count($active_languages) > 0 ) {
	?>
    		<tr valign="top" class="">
				<td class="forminp" colspan="2">
                <?php _e("Enter the translated search box text for each language for WPML to show it correct on the front end.", 'woops'); ?>
				</td>
			</tr>
    <?php
				foreach ( $active_languages as $language ) {
	?>
    		<tr valign="top" class="">
				<th class="titledesc" scope="row"><label for="woocommerce_search_box_text_<?php echo $language['code']; ?>"><?php _e('Text to Show', 'woops');?> (<?php echo $language['display_name']; ?>)</label></th>
				<td class="forminp">
                	<input type="text" class="" value="<?php if (isset($woocommerce_search_box_text[$language['code']]) ) esc_attr_e( stripslashes( $woocommerce_search_box_text[$language['code']] ) ); ?>" style="min-width:300px;" id="woocommerce_search_box_text_<?php echo $language['code']; ?>" name="woocommerce_search_box_text[<?php echo $language['code']; ?>]" /> <span class="description"><?php _e('&lt;empty&gt; shows nothing', 'woops'); ?></span>
				</td>
			</tr>
    <?php
				}
			}
			
		} else {
			$woocommerce_search_box_text = get_option('woocommerce_search_box_text', '' );
			if ( is_array( $woocommerce_search_box_text) ) $woocommerce_search_box_text = '';
	?>
            <tr valign="top" class="">
				<th class="titledesc" scope="row"><label for="woocommerce_search_box_text"><?php _e('Text to Show', 'woops');?></label></th>
				<td class="forminp">
                	<input type="text" class="" value="<?php esc_attr_e( stripslashes( $woocommerce_search_box_text ) ); ?>" style="min-width:300px;" id="woocommerce_search_box_text" name="woocommerce_search_box_text" /> <span class="description"><?php _e('&lt;empty&gt; shows nothing', 'woops'); ?></span>
				</td>
			</tr>
    <?php } ?>
	<?php
	}
	
	public function predictive_search_global_start() {
		if ( class_exists('SitePress') ) {
	?>
    	<tr valign="top"><td class="forminp" colspan="2"><?php _e('Predictive Search has detected the WPML plugin. On install a search page was auto created for each language in use. Please use the WPML String Translations plugin to make translation for plugin text for each page. If adding another language after installing Predictive Search you have to manually create a search page for it.', 'woops'); ?></td></tr>
    <?php } ?>
    	<tr valign="top"><td class="forminp" colspan="2"><?php _e('A search results page needs to be selected so that WooCommerce Predictive Search knows where to show search results. This page should have been created upon installation of the plugin, if not you need to create it.', 'woops'); ?></td></tr>
	<?php
	}
	
	public function predictive_search_global_end() {
	?>
    	<h3><?php _e('House Keeping', 'woops');?> :</h3>		
        <table class="form-table">
            <tr valign="top" class="">
				<th class="titledesc" scope="row"><label for="woocommerce_search_clean_on_deletion"><?php _e('Clean up on Deletion', 'woops');?></label></th>
				<td class="forminp">
						<label>
						<input <?php checked( get_option('woocommerce_search_clean_on_deletion'), 1); ?> type="checkbox" value="1" id="woocommerce_search_clean_on_deletion" name="woocommerce_search_clean_on_deletion">
						<?php _e('Check this box and if you ever delete this plugin it will completely remove all tables and data it created, leaving no trace it was ever here.', 'woops');?></label> <br>
				</td>
			</tr>
		</table>
    <?php
		echo '</div><div class="section" id="all-results-pages">';	
	}
	
	public function predictive_search_results_end() {
		echo '</div><div class="section" id="exclude-content">';	
	}
	
	public function predictive_search_excludes_end() {
		echo '</div><div class="section" id="search-function">';	
	}
	
	public function predictive_search_code_start() {
		echo '<tr valign="top"><td class="forminp" colspan="2">';
		?>
        <?php _e('Copy and paste this global function into your themes header.php file to replace any existing search function. (Be sure to delete the existing WordPress, WooCommerce or Theme search function)', 'woops');?>
            <br /><code>&lt;?php if(function_exists('woo_predictive_search_widget')) woo_predictive_search_widget(); ?&gt;</code>
            <br /><br />
            <h3><?php _e('Customize Search Function values', 'woops');?> :</h3>
		<?php
			_e("The values you set here will be shown when you add the global search function to your header.php file. After adding the global function to your header.php file you can change the values here and 'Update' and they will be auto updated in the function.", "woops");
		echo '</td></tr>';
	}

    /**
     * settings_tab_action()
     *
     * Do this when viewing our custom settings tab(s). One function for all tabs.
    */
    public function settings_tab_action() {
    	global $woocommerce_settings;
		
		// Determine the current tab in effect.
        $current_tab = $this->get_tab_in_view(current_filter(), 'woocommerce_settings_tabs_');

        // Hook onto this from another function to keep things clean.
        // do_action( 'woocommerce_newsletter_settings' );

		if(isset($_REQUEST['saved']) && get_option("woo_predictive_search_message") != ''){
			echo '<div id="message" class="updated fade"><p>'.get_option("woo_predictive_search_message").'</p></div>';
			update_option('woo_predictive_search_message', '');
		}
		?>
        <style>
		.view-docs-container {
			position:relative;	
		}
		.a3-view-docs-button {
			background-color: #FFFFE0 !important;
			border: 1px solid #E6DB55 !important;
			text-shadow:none !important;
			font-weight:normal !important;
			margin-left:0 !important;
			margin-bottom:5px !important;
			position: absolute !important;
			top: -36px !important;
			left:244px !important;
		}
		</style>
        <div class="a3_subsubsub_section">
        	<ul class="subsubsub">
            	<li><a href="#global-settings" class="current"><?php _e('Global Settings', 'woops'); ?></a> | </li>
                <li><a href="#all-results-pages"><?php _e('All Results Pages', 'woops'); ?></a> | </li>
                <li><a href="#exclude-content"><?php _e('Exclude Content', 'woops'); ?></a> | </li>
                <li><a href="#search-function"><?php _e('Search Function', 'woops'); ?></a></li>
			</ul>
            <br class="clear">
            <div class="section" id="global-settings">
            <?php
            do_action('woocommerce_ps_settings');
    
            // Display settings for this tab (make sure to add the settings to the tab).
            woocommerce_admin_fields($woocommerce_settings[$current_tab]);
            ?>
            </div>
        </div>
        	<script type="text/javascript">
				jQuery(window).load(function(){
					// Subsubsub tabs
					jQuery('div.a3_subsubsub_section ul.subsubsub li a:eq(0)').addClass('current');
					jQuery('div.a3_subsubsub_section .section:gt(0)').hide();

					jQuery('div.a3_subsubsub_section ul.subsubsub li a').click(function(){
						var $clicked = jQuery(this);
						var $section = $clicked.closest('.a3_subsubsub_section');
						var $target  = $clicked.attr('href');

						$section.find('a').removeClass('current');

						if ( $section.find('.section:visible').size() > 0 ) {
							$section.find('.section:visible').fadeOut( 100, function() {
								$section.find( $target ).fadeIn('fast');
							});
						} else {
							$section.find( $target ).fadeIn('fast');
						}

						$clicked.addClass('current');
						jQuery('#last_tab').val( $target );

						return false;
					});

					<?php if (isset($_GET['subtab']) && $_GET['subtab']) echo 'jQuery("div.a3_subsubsub_section ul.subsubsub li a[href=#'.$_GET['subtab'].']").click();'; ?>
				});
			</script>
        <?php
		add_action('admin_footer', array('WC_Predictive_Search_Hook_Filter', 'admin_add_scripts'), 10);
	}

	/**
     * add_settings_fields()
     *
     * Add settings fields for each tab.
    */
    public function add_settings_fields() {
    	global $woocommerce_settings;

        // Load the prepared form fields.
        $this->init_form_fields();

        if ( is_array($this->fields) ) :
        	foreach ( $this->fields as $k => $v ) :
                $woocommerce_settings[$k] = $v;
            endforeach;
        endif;
	}

    /**
    * get_tab_in_view()
    *
    * Get the tab current in view/processing.
    */
    public function get_tab_in_view($current_filter, $filter_base) {
    	return str_replace($filter_base, '', $current_filter);
    }
	

    /**
     * init_form_fields()
     *
     * Prepare form fields to be used in the various tabs.
     */
	public function init_form_fields() {
		global $wpdb;
		$all_products = array();
		$all_posts = array();
		$all_pages = array();
		$all_p_categories = array();
		$all_p_tags = array();
		$results_products = $wpdb->get_results("SELECT ID, post_title FROM ".$wpdb->prefix."posts WHERE post_type='product' AND post_status='publish' ORDER BY post_title ASC");
		if ($results_products) {
			foreach($results_products as $product_data) {
				$all_products[$product_data->ID] = $product_data->post_title;
			}
		}
		$results_posts = $wpdb->get_results("SELECT ID, post_title FROM ".$wpdb->prefix."posts WHERE post_type='post' AND post_status='publish' ORDER BY post_title ASC");
		if ($results_posts) {
			foreach($results_posts as $post_data) {
				$all_posts[$post_data->ID] = $post_data->post_title;
			}
		}
		$results_pages = $wpdb->get_results("SELECT ID, post_title FROM ".$wpdb->prefix."posts WHERE post_type='page' AND post_status='publish' ORDER BY post_title ASC");
		if ($results_pages) {
			foreach($results_pages as $page_data) {
				$all_pages[$page_data->ID] = $page_data->post_title;
			}
		}
		$results_p_categories = $wpdb->get_results("SELECT t.term_id, t.name FROM ".$wpdb->prefix."terms AS t INNER JOIN ".$wpdb->prefix."term_taxonomy AS tt ON(t.term_id=tt.term_id) WHERE tt.taxonomy='product_cat' ORDER BY t.name ASC");
		if ($results_p_categories) {
			foreach($results_p_categories as $p_categories_data) {
				$all_p_categories[$p_categories_data->term_id] = $p_categories_data->name;
			}
		}
		$results_p_tags = $wpdb->get_results("SELECT t.term_id, t.name FROM ".$wpdb->prefix."terms AS t INNER JOIN ".$wpdb->prefix."term_taxonomy AS tt ON(t.term_id=tt.term_id) WHERE tt.taxonomy='product_tag' ORDER BY t.name ASC");
		if ($results_p_tags) {
			foreach($results_p_tags as $p_tags_data) {
				$all_p_tags[$p_tags_data->term_id] = $p_tags_data->name;
			}
		}
		
  		// Define settings			
     	$this->fields['ps_settings'] = apply_filters('woocommerce_ps_settings_fields', array(
		
			array(
            	'name' => __( 'Focus Keywords', 'woops' ),
                'type' => 'title',
                'desc' => '<div class="view-docs-container"><a class="add-new-h2 a3-view-docs-button" target="_blank" href="'.WOO_PREDICTIVE_SEARCH_DOCS_URI.'#section-11" >'.__('View Docs', 'woops').'</a></div>',
          		'id' => 'predictive_search_focus_keywords_start'
           	),
			array(  
				'name' 		=> __( 'Predictive Search', 'woops' ),
				'desc' 		=> __("Activate to optimize your sites content with Predictive Search 'Focus keywords'", 'woops'),
				'id' 		=> 'woocommerce_search_focus_enable',
				'type' 		=> 'checkbox',
				'std' 		=> 1,
				'default'	=> 'yes'
			),
			array(  
				'name' 		=> __( "Activate SEO 'Focus Keywords'", 'woops' ),
				'desc' 		=> '',
				'id' 		=> 'woocommerce_search_focus_plugin',
				'css' 		=> 'min-width:300px;',
				'class'		=> 'chzn-select',
				'type' 		=> 'select',
				'std' 		=> 'none',
				'default'	=> 'none',
				'options'	=> array(
						'none'						=> __( 'Select SEO plugin', 'woops' ) ,							
						'yoast_seo_plugin'				=> __( 'Yoast WordPress SEO', 'woops' ) ,
						'all_in_one_seo_plugin'		=> __( 'All in One SEO', 'woops' ) ,
					),
			),
			array('type' => 'sectionend', 'id' => 'predictive_search_focus_keywords_end'),
			
			array(
            	'name' => __( 'Global Search Box Text', 'woops' ),
                'type' => 'title',
                'desc' => '',
          		'id' => 'predictive_search_searchbox_text_start'
           	),
						
			array('type' => 'sectionend', 'id' => 'predictive_search_searchbox_text_end'),
			
      		array(
            	'name' => __('Search Page Configuration', 'woops'),
                'type' => 'title',
                'desc' => '',
          		'id' => 'predictive_search_global_start'
           	),
			array(  
				'name' => __( 'Search Page', 'woops' ),
				'desc' 		=> __('Page contents:', 'woops').' [woocommerce_search]',
				'id' 		=> 'woocommerce_search_page_id',
				'type' 		=> 'single_select_page',
				'std' 		=> '',
				'default'	=> '',
				'class'		=> 'chosen_select_nostd',
				'css' 		=> 'min-width:300px;',
				'desc_tip'	=>  false
			),
			array('type' => 'sectionend', 'id' => 'predictive_search_global_end'),
			
			array(
            	'name' => __( 'Search results page settings', 'woops' ),
                'type' => 'title',
                'desc' => '<div class="view-docs-container"><a class="add-new-h2 a3-view-docs-button" target="_blank" href="'.WOO_PREDICTIVE_SEARCH_DOCS_URI.'#section-13" >'.__('View Docs', 'woops').'</a></div>',
          		'id' => 'predictive_search_results_start'
           	),
			array(  
				'name' => __( 'Results', 'woops' ),
				'desc' 		=> __('The number of results to show before endless scroll click to see more results.', 'woops'),
				'id' 		=> 'woocommerce_search_result_items',
				'type' 		=> 'text',
				'css' 		=> 'width:30px;',
				'std' 		=> 10,
				'default'	=> 10
			),
			array(  
				'name' => __( 'Description character count', 'woops' ),
				'desc' 		=> __('The number of characters from product descriptions that shows with each search result.', 'woops'),
				'id' 		=> 'woocommerce_search_text_lenght',
				'type' 		=> 'text',
				'css' 		=> 'width:30px;',
				'std' 		=> 100,
				'default'	=> 100
			),
			array(  
				'name' 		=> __( 'SKU', 'woops' ),
				'desc' 		=> __('Show product SKU with search results', 'woops'),
				'id' 		=> 'woocommerce_search_sku_enable',
				'type' 		=> 'checkbox',
				'std' 		=> 1,
				'default'	=> 'yes'
			),
			array(  
				'name' 		=> __( 'Price', 'woops' ),
				'desc' 		=> __('Show product price with search results', 'woops'),
				'id' 		=> 'woocommerce_search_price_enable',
				'type' 		=> 'checkbox',
				'std' 		=> 1,
				'default'	=> 'yes'
			),
			array(  
				'name' 		=> __( 'Add to cart', 'woops' ),
				'desc' 		=> __('Show Add to cart button with search results', 'woops'),
				'id' 		=> 'woocommerce_search_addtocart_enable',
				'type' 		=> 'checkbox',
				'std' 		=> 1,
				'default'	=> 'yes'
			),
			array(  
				'name' 		=> __( 'Product Categories', 'woops' ),
				'desc' 		=> __('Show categories with search results', 'woops'),
				'id' 		=> 'woocommerce_search_categories_enable',
				'type' 		=> 'checkbox',
				'std' 		=> 1,
				'default'	=> 'yes'
			),
			array(  
				'name' 		=> __( 'Product Tags', 'woops' ),
				'desc' 		=> __('Show tags with search results', 'woops'),
				'id' 		=> 'woocommerce_search_tags_enable',
				'type' 		=> 'checkbox',
				'std' 		=> 1,
				'default'	=> 'yes'
			),
			array('type' => 'sectionend', 'id' => 'predictive_search_results_end'),
			
			array(
            	'name' => __( 'Exclude From Predictive Search', 'woops' ),
                'type' => 'title',
                'desc' => '<div class="view-docs-container"><a class="add-new-h2 a3-view-docs-button" target="_blank" href="'.WOO_PREDICTIVE_SEARCH_DOCS_URI.'#section-12" >'.__('View Docs', 'woops').'</a></div>',
          		'id' => 'predictive_search_excludes_start'
           	),
			array(  
				'name' 		=> __( 'Exclude Products', 'woops' ),
				'desc' 		=> '',
				'id' 		=> 'woocommerce_search_exclude_products',
				'type' 		=> 'wc_predictive_search_multi_select',
				'std' 		=> '',
				'default'	=> '',
				'placeholder' => __( 'Choose Products', 'woops' ),
				'options'	=> $all_products,
			),
			array(  
				'name' 		=> __( 'Exclude Product Categories', 'woops' ),
				'desc' 		=> '',
				'id' 		=> 'woocommerce_search_exclude_p_categories',
				'type' 		=> 'wc_predictive_search_multi_select',
				'std' 		=> '',
				'default'	=> '',
				'placeholder' => __( 'Choose Product Categories', 'woops' ),
				'options'	=> $all_p_categories,
			),
			array(  
				'name' 		=> __( 'Exclude Product Tags', 'woops' ),
				'desc' 		=> '',
				'id' 		=> 'woocommerce_search_exclude_p_tags',
				'type' 		=> 'wc_predictive_search_multi_select',
				'std' 		=> '',
				'default'	=> '',
				'placeholder' => __( 'Choose Product Tags', 'woops' ),
				'options'	=> $all_p_tags,
			),
			array(  
				'name' 		=> __( 'Exclude Posts', 'woops' ),
				'desc' 		=> '',
				'id' 		=> 'woocommerce_search_exclude_posts',
				'type' 		=> 'wc_predictive_search_multi_select',
				'std' 		=> '',
				'default'	=> '',
				'placeholder' => __( 'Choose Posts', 'woops' ),
				'options'	=> $all_posts,
			),
			array(  
				'name' 		=> __( 'Exclude Pages', 'woops' ),
				'desc' 		=> '',
				'id' 		=> 'woocommerce_search_exclude_pages',
				'type' 		=> 'wc_predictive_search_multi_select',
				'std' 		=> '',
				'default'	=> '',
				'placeholder' => __( 'Choose Pages', 'woops' ),
				'options'	=> $all_pages,
			),
			array('type' => 'sectionend', 'id' => 'predictive_search_excludes_end'),
			
			
			array(
            	'name' => __( 'Predictive Search Function', 'woops' ),
                'type' => 'title',
                'desc' => '<div class="view-docs-container"><a class="add-new-h2 a3-view-docs-button" target="_blank" href="'.WOO_PREDICTIVE_SEARCH_DOCS_URI.'#section-14" >'.__('View Docs', 'woops').'</a></div>',
          		'id' => 'predictive_search_code_start'
           	),
			array(  
				'name' => __( 'Product name', 'woops' ),
				'desc' 		=> __('Number of Product Name to show in search field drop-down. Leave &lt;empty&gt; for not activated', 'woops'),
				'id' 		=> 'woocommerce_search_product_items',
				'type' 		=> 'text',
				'css' 		=> 'width:30px;',
			),
			array(  
				'name' => __( 'Product SKU', 'woops' ),
				'desc' 		=> __('Number of Product SKU to show in search field drop-down. Leave &lt;empty&gt; for not activated', 'woops'),
				'id' 		=> 'woocommerce_search_p_sku_items',
				'type' 		=> 'text',
				'css' 		=> 'width:30px;',
			),
			array(  
				'name' => __( 'Product category', 'woops' ),
				'desc' 		=> __('Number of Product Categories to show in search field drop-down. Leave &lt;empty&gt; for not activated', 'woops'),
				'id' 		=> 'woocommerce_search_p_cat_items',
				'type' 		=> 'text',
				'css' 		=> 'width:30px;',
			),
			array(  
				'name' => __( 'Product tag', 'woops' ),
				'desc' 		=> __('Number of Product Tags to show in search field drop-down. Leave &lt;empty&gt; for not activated', 'woops'),
				'id' 		=> 'woocommerce_search_p_tag_items',
				'type' 		=> 'text',
				'css' 		=> 'width:30px;',
			),
			array(  
				'name' => __( 'Post', 'woops' ),
				'desc' 		=> __('Number of Posts to show in search field drop-down. Leave &lt;empty&gt; for not activated', 'woops'),
				'id' 		=> 'woocommerce_search_post_items',
				'type' 		=> 'text',
				'css' 		=> 'width:30px;',
			),
			array(  
				'name' => __( 'Page', 'woops' ),
				'desc' 		=> __('Number of Pages to show in search field drop-down. Leave &lt;empty&gt; for not activated', 'woops'),
				'id' 		=> 'woocommerce_search_page_items',
				'type' 		=> 'text',
				'css' 		=> 'width:30px;',
			),
			array(  
				'name' => __( 'Price', 'woops' ),
				'desc' 		=> __('Show Product prices', 'woops'),
				'id' 		=> 'woocommerce_search_show_price',
				'type' 		=> 'checkbox',
				'std' 		=> 1,
				'default'	=> 'yes',
			),
			array(  
				'name' => __( 'Description Characters', 'woops' ),
				'desc' 		=> __('Number of characters from product description to show in search field drop-down. Default value is "100".', 'woops'),
				'id' 		=> 'woocommerce_search_character_max',
				'type' 		=> 'text',
				'css' 		=> 'width:30px;',
			),
			array(  
				'name' => __( 'Width', 'woops' ),
				'desc' 		=> 'px. '.__('Leave &lt;empty&gt; for 100% wide', 'woops'),
				'id' 		=> 'woocommerce_search_width',
				'type' 		=> 'text',
				'css' 		=> 'width:30px;',
			),
			array(  
				'name' => __( 'Padding top', 'woops' ),
				'desc' 		=> 'px',
				'id' 		=> 'woocommerce_search_padding_top',
				'type' 		=> 'text',
				'css' 		=> 'width:30px;',
			),
			array(  
				'name' => __( 'Padding bottom', 'woops' ),
				'desc' 		=> 'px',
				'id' 		=> 'woocommerce_search_padding_bottom',
				'type' 		=> 'text',
				'css' 		=> 'width:30px;',
			),
			array(  
				'name' => __( 'Padding left', 'woops' ),
				'desc' 		=> 'px',
				'id' 		=> 'woocommerce_search_padding_left',
				'type' 		=> 'text',
				'css' 		=> 'width:30px;',
			),
			array(  
				'name' => __( 'Padding right', 'woops' ),
				'desc' 		=> 'px',
				'id' 		=> 'woocommerce_search_padding_right',
				'type' 		=> 'text',
				'css' 		=> 'width:30px;',
			),
			array(  
				'name' => __( 'Custom style', 'woops' ),
				'desc' 		=> __('Put other custom style for the Predictive search box', 'woops'),
				'id' 		=> 'woocommerce_search_custom_style',
				'type' 		=> 'text',
				'css' 		=> 'min-width:300px;',
			),
			array(  
				'name' => __( 'Global search', 'woops' ),
				'desc' 		=> __('Set global search or search in current product category or current product tag. "Checked" to activate global search.', 'woops'),
				'id' 		=> 'woocommerce_search_global_search',
				'type' 		=> 'checkbox',
				'std' 		=> 1,
				'default'	=> 'yes',
			),
			array('type' => 'sectionend', 'id' => 'predictive_search_code_end'),
        ));
	}

    /**
     * save_settings()
     *
     * Save settings in a single field in the database for each tab's fields (one field per tab).
     */
     public function save_settings() {
     	global $woocommerce_settings;

        // Make sure our settings fields are recognised.
        $this->add_settings_fields();

        $current_tab = $this->get_tab_in_view(current_filter(), 'woocommerce_update_options_');

		woocommerce_update_options($woocommerce_settings[$current_tab]);
		
		update_option('woocommerce_search_exclude_products', (array) $_REQUEST['woocommerce_search_exclude_products']);
		update_option('woocommerce_search_exclude_p_categories', (array) $_REQUEST['woocommerce_search_exclude_p_categories']);
		update_option('woocommerce_search_exclude_p_tags', (array) $_REQUEST['woocommerce_search_exclude_p_tags']);
		update_option('woocommerce_search_exclude_posts', (array) $_REQUEST['woocommerce_search_exclude_posts']);
		update_option('woocommerce_search_exclude_pages', (array) $_REQUEST['woocommerce_search_exclude_pages']);
		
		if ( isset($_REQUEST['woocommerce_search_clean_on_deletion']) ) {
			update_option('woocommerce_search_clean_on_deletion',  $_REQUEST['woocommerce_search_clean_on_deletion']);
		} else { 
			update_option('woocommerce_search_clean_on_deletion',  0);
			$uninstallable_plugins = (array) get_option('uninstall_plugins');
			unset($uninstallable_plugins[WOOPS_NAME]);
			update_option('uninstall_plugins', $uninstallable_plugins);
		}
		
		if ( isset($_REQUEST['woocommerce_search_box_text']) ) {
			update_option('woocommerce_search_box_text',  $_REQUEST['woocommerce_search_box_text']);
		}
	}

    /** Helper functions ***************************************************** */
         
    /**
     * Gets a setting
     */
    public function setting($key) {
		return get_option($key);
	}
	
	public function wc_predictive_search_multi_select($value) {
		if ( $value['desc_tip'] === true ) {
    		$description = '<img class="help_tip" data-tip="' . esc_attr( $value['desc'] ) . '" src="' . $woocommerce->plugin_url() . '/assets/images/help.png" />';
    	} elseif ( $value['desc_tip'] ) {
    		$description = '<img class="help_tip" data-tip="' . esc_attr( $value['desc_tip'] ) . '" src="' . $woocommerce->plugin_url() . '/assets/images/help.png" />';
    	} else {
    		$description = '<span class="description">' . $value['desc'] . '</span>';
    	}
		$selections = (array) get_option($value['id']);
	?>
    	<tr valign="top">
            <th scope="row" class="titledesc">
                <label for="<?php echo esc_attr( $value['id'] ); ?>"><?php echo $value['name']; ?></label>
            </th>
            <td class="forminp">
                <select multiple="multiple" name="<?php echo esc_attr( $value['id'] ); ?>[]" data-placeholder="<?php echo $value['placeholder']; ?>" style="display:none; width:600px; <?php echo esc_attr( $value['css'] ); ?>" class="chzn-select <?php if (isset($value['class'])) echo $value['class']; ?>">
                <?php
                foreach ($value['options'] as $key => $val) {
                ?>
                    <option value="<?php echo esc_attr( $key ); ?>" <?php selected( in_array($key, $selections), true ); ?>><?php echo $val ?></option>
                <?php
                }
                ?>
                </select> <?php echo $description; ?>
            </td>
		</tr>
    <?php
	}	
}
?>