<?php
/**
 * WooCommerce Predictive Search Hook Filter
 *
 * Hook anf Filter into woocommerce plugin
 *
 * Table Of Contents
 *
 * plugins_loaded()
 * get_result_popup()
 * add_frontend_script()
 * add_frontend_style()
 * add_query_vars()
 * add_rewrite_rules()
 * custom_rewrite_rule()
 * search_by_title_only()
 * posts_request_unconflict_role_scoper_plugin()
 * admin_add_scripts()
 * plugin_extra_links()
 */
class WC_Predictive_Search_Hook_Filter 
{
	
	public static function plugins_loaded() {
		global $woocommerce_search_page_id;
		global $wc_predictive_id_excludes;
		
		$woocommerce_search_page_id = WC_Predictive_Search::get_page_id_from_shortcode( 'woocommerce_search', 'woocommerce_search_page_id');
		WC_Predictive_Search::get_id_excludes();
		WC_Predictive_Search::wpml_register_string();
	}
	
	public static function get_result_popup() {
		check_ajax_referer( 'woops-get-result-popup', 'security' );
		global $woocommerce_search_page_id;
		global $wpdb;
		
		$support_wpml = false;
		$inner_wpml_table = '';
		$where_wpml = '';
		if ( class_exists('SitePress') ) {
			$support_wpml = true;
			$current_lang = $_REQUEST['lang'];
			$inner_wpml_table = "INNER JOIN ".$wpdb->prefix."icl_translations AS ic ON ic.element_id = tt.term_taxonomy_id";
			$where_wpml = " AND ic.language_code = '".$current_lang."'";
		}

		add_filter( 'posts_search', array('WC_Predictive_Search_Hook_Filter', 'search_by_title_only'), 500, 2 );
		add_filter( 'posts_orderby', array('WC_Predictive_Search_Hook_Filter', 'predictive_posts_orderby'), 500, 2 );
		add_filter( 'get_meta_sql', array('WC_Predictive_Search_Hook_Filter', 'remove_where_on_focuskw_meta'), 500, 6 );
		add_filter( 'posts_request', array('WC_Predictive_Search_Hook_Filter', 'posts_request_unconflict_role_scoper_plugin'), 500, 2);
		
		global $wc_predictive_id_excludes;
		
		$rs_headings = array();
		$rs_items = array();
		$rs_footers = array();
		$row = 6;
		$text_lenght = 100;
		$show_price = 0;
		$search_keyword = '';
		$pcat_slug = '';
		$ptag_slug = '';
		$cat_slug = '';
		$tag_slug = '';
		$found_items = false;
		$total_product = $total_p_sku = $total_post = $total_page = $total_pcat = $total_ptag = 0;
		$items_search_default = WC_Predictive_Search_Widgets::get_items_search();
		$search_in_default = array();
		foreach ($items_search_default as $key => $data) {
			if ($data['number'] > 0) {
				$search_in_default[$key] = $data['number'];
			}
		}
		if (isset($_REQUEST['row']) && $_REQUEST['row'] > 0) $row = stripslashes( strip_tags( $_REQUEST['row'] ) );
		if (isset($_REQUEST['text_lenght']) && $_REQUEST['text_lenght'] >= 0) $text_lenght = stripslashes( strip_tags( $_REQUEST['text_lenght'] ) );
		if (isset($_REQUEST['show_price']) && trim($_REQUEST['show_price']) != '') $show_price = stripslashes( strip_tags( $_REQUEST['show_price'] ) );
		if (isset($_REQUEST['q']) && trim($_REQUEST['q']) != '') $search_keyword = stripslashes( strip_tags( $_REQUEST['q'] ) );
		if (isset($_REQUEST['pcat']) && trim($_REQUEST['pcat']) != '') $pcat_slug = stripslashes( strip_tags( $_REQUEST['pcat'] ) );
		if (isset($_REQUEST['ptag']) && trim($_REQUEST['ptag']) != '') $ptag_slug = stripslashes( strip_tags( $_REQUEST['ptag'] ) );
		if (isset($_REQUEST['scat']) && trim($_REQUEST['scat']) != '') $cat_slug = stripslashes( strip_tags( $_REQUEST['scat'] ) );
		if (isset($_REQUEST['stag']) && trim($_REQUEST['stag']) != '') $tag_slug = stripslashes( strip_tags( $_REQUEST['stag'] ) );
		if (isset($_REQUEST['search_in']) && trim($_REQUEST['search_in']) != '') $search_in = unserialize(stripslashes( strip_tags( $_REQUEST['search_in'] ) ) );
		if (!is_array($search_in) || count($search_in) < 1 || array_sum($search_in) < 1) $search_in = $search_in_default;
		
		$search_list = array();
		foreach ($search_in as $key => $number) {
			if ($number > 0)
				$search_list[$key] = $key;
		}
		
		$woocommerce_search_focus_enable = get_option('woocommerce_search_focus_enable');
		$woocommerce_search_focus_plugin = get_option('woocommerce_search_focus_plugin');
		$meta_query_args = array();
		if ( empty($woocommerce_search_focus_enable) || $woocommerce_search_focus_enable == 'yes' ) {
			$meta_query_args['relation'] = 'OR';
			$meta_query_args[] = array( 'key' => '_predictive_search_focuskw', 'value' => $search_keyword, 'compare' => 'LIKE');
					
			if ($woocommerce_search_focus_plugin == 'yoast_seo_plugin') 
				$meta_query_args[] = array( 'key' => '_yoast_wpseo_focuskw', 'value' => $search_keyword, 'compare' => 'LIKE');
			elseif ($woocommerce_search_focus_plugin == 'all_in_one_seo_plugin') 
				$meta_query_args[] = array( 'key' => '_aioseop_keywords', 'value' => $search_keyword, 'compare' => 'LIKE');
		}
		
		if ($search_keyword != '') {
			
			if ( isset($search_in['product']) && $search_in['product'] > 0) {
				$extra_parameter_product = '';
								
				$row = $search_in['product'];
				$end_row = $row;
				$args = array( 's' => $search_keyword, 'numberposts' => $row+1, 'offset'=> 0, 'orderby' => 'predictive', 'order' => 'ASC', 'post_type' => 'product', 'post_status' => 'publish', 'exclude' => $wc_predictive_id_excludes['exclude_products'], 'suppress_filters' => FALSE);
				
				if ( count($meta_query_args) > 0 ) $args['meta_query'] = $meta_query_args;
				
				if ($pcat_slug != '') {
					$args['tax_query'] = array( array('taxonomy' => 'product_cat', 'field' => 'slug', 'terms' => $pcat_slug) );
					if (get_option('permalink_structure') == '')
						$extra_parameter_product .= '&pcat='.$pcat_slug;
					else
						$extra_parameter_product .= '/pcat/'.$pcat_slug;
				} elseif($ptag_slug != '') {
					$args['tax_query'] = array( array('taxonomy' => 'product_tag', 'field' => 'slug', 'terms' => $ptag_slug) );
					if (get_option('permalink_structure') == '')
						$extra_parameter_product .= '&ptag='.$ptag_slug;
					else
						$extra_parameter_product .= '/ptag/'.$ptag_slug;
				}
				
				$search_products = get_posts($args);
				
				$total_product = count($search_products);
				if ( $search_products && $total_product > 0 ) {
					$found_items = true;
					$rs_headings['product'] = "<div class='ajax_search_content_title'>". ( function_exists('icl_t') ? icl_t('WooCommerce Predictive Search', 'Product Name', __('Product Name', 'woops') ) : __('Product Name', 'woops') ) ."</div>|#|$search_keyword\n";
					$rs_items['product'] = '';
					foreach ( $search_products as $product ) {
						$link_detail = get_permalink($product->ID);
						$avatar = WC_Predictive_Search::woops_get_product_thumbnail($product->ID,'shop_catalog',64,64);
						$product_description = WC_Predictive_Search::woops_limit_words(strip_tags( WC_Predictive_Search::strip_shortcodes( strip_shortcodes (str_replace("\n", "", $product->post_content) ) ) ),$text_lenght,'...');
						if (trim($product_description) == '') $product_description = WC_Predictive_Search::woops_limit_words(strip_tags( WC_Predictive_Search::strip_shortcodes( strip_shortcodes( str_replace("\n", "", $product->post_excerpt) ) ) ),$text_lenght,'...');
						
						$price_html = '';
						if ( $show_price == 1)
							$price_html = WC_Predictive_Search_Shortcodes::get_product_price_dropdown($product->ID);
						
						$item_html = '<div class="ajax_search_content"><div class="result_row"><a href="'.$link_detail.'"><span class="rs_avatar">'.$avatar.'</span><div class="rs_content_popup"><span class="rs_name">'.stripslashes( $product->post_title).'</span>'.$price_html.'<span class="rs_description">'.$product_description.'</span></div></a></div></div>';
						$rs_items['product'] .= "$item_html|$link_detail|".stripslashes( $product->post_title)."\n";
						$end_row--;
						if ($end_row < 1) break;
					}
				}
			}
			
			if ( isset($search_in['p_sku']) && $search_in['p_sku'] > 0) {
				$extra_parameter_product = '';
								
				$row = $search_in['p_sku'];
				$end_row = $row;
				$args = array( 's' => $search_keyword, 'numberposts' => $row+1, 'offset'=> 0, 'orderby' => 'predictive', 'order' => 'ASC', 'post_type' => 'product', 'post_status' => 'publish', 'meta_key' => '_sku', 'exclude' => $wc_predictive_id_excludes['exclude_products'], 'suppress_filters' => FALSE);
				if ($pcat_slug != '') {
					$args['tax_query'] = array( array('taxonomy' => 'product_cat', 'field' => 'slug', 'terms' => $pcat_slug) );
					if (get_option('permalink_structure') == '')
						$extra_parameter_product .= '&pcat='.$pcat_slug;
					else
						$extra_parameter_product .= '/pcat/'.$pcat_slug;
				} elseif($ptag_slug != '') {
					$args['tax_query'] = array( array('taxonomy' => 'product_tag', 'field' => 'slug', 'terms' => $ptag_slug) );
					if (get_option('permalink_structure') == '')
						$extra_parameter_product .= '&ptag='.$ptag_slug;
					else
						$extra_parameter_product .= '/ptag/'.$ptag_slug;
				}
				
				$search_products = get_posts($args);
				
				$total_p_sku = count($search_products);
				if ( $search_products && $total_p_sku > 0 ) {
					$found_items = true;
					$rs_headings['p_sku'] = "<div class='ajax_search_content_title'>". ( function_exists('icl_t') ? icl_t('WooCommerce Predictive Search', 'Product SKU', 'Product SKU') : __('Product SKU', 'woops') ) ."</div>|#|$search_keyword\n";
					$rs_items['p_sku'] = '';
					foreach ( $search_products as $product ) {
						$link_detail = get_permalink($product->ID);
						$avatar = WC_Predictive_Search::woops_get_product_thumbnail($product->ID,'shop_catalog',64,64);
						$product_sku = stripslashes( get_post_meta($product->ID, '_sku', true) );
						
						$price_html = '';
						if ( $show_price == 1)
							$price_html = WC_Predictive_Search_Shortcodes::get_product_price_dropdown($product->ID);
							
						$item_html = '<div class="ajax_search_content"><div class="result_row"><a href="'.$link_detail.'"><span class="rs_avatar">'.$avatar.'</span><div class="rs_content_popup"><span class="rs_name">'.$product_sku.'</span><span class="rs_name">'.stripslashes( $product->post_title).'</span>'.$price_html.'</div></a></div></div>';
						$rs_items['p_sku'] .= "$item_html|$link_detail|".$product_sku."\n";
						$end_row--;
						if ($end_row < 1) break;
					}
				}
			}
			
			if ( isset($search_in['post']) && $search_in['post'] > 0) {
				$extra_parameter_post = '';
				
				$row = $search_in['post'];
				$end_row = $row;
				$args = array( 's' => $search_keyword, 'numberposts' => $row+1, 'offset'=> 0, 'orderby' => 'predictive', 'order' => 'ASC', 'post_type' => 'post', 'post_status' => 'publish', 'exclude' => $wc_predictive_id_excludes['exclude_posts'], 'suppress_filters' => FALSE);
				
				if ( count($meta_query_args) > 0 ) $args['meta_query'] = $meta_query_args;
				
				if ($cat_slug != '') {
					$args['category_name'] = $cat_slug;
					if (get_option('permalink_structure') == '')
						$extra_parameter_post .= '&scat='.$cat_slug;
					else
						$extra_parameter_post .= '/scat/'.$cat_slug;
				} elseif($tag_slug != '') {
					$args['tag'] = $tag_slug;
					if (get_option('permalink_structure') == '')
						$extra_parameter_post .= '&stag='.$tag_slug;
					else
						$extra_parameter_post .= '/stag/'.$tag_slug;
				}
								
				$search_posts = get_posts($args);
				$total_post = count($search_posts);
				if ( $search_posts && $total_post > 0 ) {
					$found_items = true;
					$rs_headings['post'] = "<div class='ajax_search_content_title'>". ( function_exists('icl_t') ? icl_t('WooCommerce Predictive Search', 'Posts', __('Posts', 'woops') ) : __('Posts', 'woops') ) ."</div>|#|$search_keyword\n";
					$rs_items['post'] = '';
					foreach ( $search_posts as $item ) {
						$link_detail = get_permalink($item->ID);
						$avatar = WC_Predictive_Search::woops_get_product_thumbnail($item->ID,'shop_catalog',64,64);
						$product_description = WC_Predictive_Search::woops_limit_words(strip_tags( WC_Predictive_Search::strip_shortcodes( strip_shortcodes( str_replace("\n", "", $item->post_content) ) ) ),$text_lenght,'...');
						if (trim($product_description) == '') $product_description = WC_Predictive_Search::woops_limit_words(strip_tags( WC_Predictive_Search::strip_shortcodes( strip_shortcodes( str_replace("\n", "", $item->post_excerpt) ) ) ),$text_lenght,'...');
						
						$item_html = '<div class="ajax_search_content"><div class="result_row"><a href="'.$link_detail.'"><span class="rs_avatar">'.$avatar.'</span><div class="rs_content_popup"><span class="rs_name">'.stripslashes( $item->post_title).'</span><span class="rs_description">'.$product_description.'</span></div></a></div></div>';
						$rs_items['post'] .= "$item_html|$link_detail|".stripslashes( $item->post_title)."\n";
						$end_row--;
						if ($end_row < 1) break;
					}
				}
			}
			
			if ( isset($search_in['page']) && $search_in['page'] > 0) {
				$row = $search_in['page'];
				$end_row = $row;
				$args = array( 's' => $search_keyword, 'numberposts' => $row+1, 'offset'=> 0, 'orderby' => 'predictive', 'order' => 'ASC', 'post_type' => 'page', 'post_status' => 'publish', 'exclude' => $wc_predictive_id_excludes['exclude_pages'], 'suppress_filters' => FALSE);
				
				if ( count($meta_query_args) > 0 ) $args['meta_query'] = $meta_query_args;
				
				$search_pages = get_posts($args);
				$total_page = count($search_pages);
				if ( $search_pages && $total_page > 0 ) {
					$found_items = true;
					$rs_headings['page'] = "<div class='ajax_search_content_title'>". ( function_exists('icl_t') ? icl_t('WooCommerce Predictive Search', 'Pages', __('Pages', 'woops') ) : __('Pages', 'woops') ) ."</div>|#|$search_keyword\n";
					$rs_items['page'] = '';
					foreach ( $search_pages as $item ) {
						$link_detail = get_permalink($item->ID);
						$avatar = WC_Predictive_Search::woops_get_product_thumbnail($item->ID,'shop_catalog',64,64);
						$product_description = WC_Predictive_Search::woops_limit_words(strip_tags( WC_Predictive_Search::strip_shortcodes( strip_shortcodes( str_replace("\n", "", $item->post_content) ) ) ),$text_lenght,'...');
						if (trim($product_description) == '') $product_description = WC_Predictive_Search::woops_limit_words(strip_tags( WC_Predictive_Search::strip_shortcodes( strip_shortcodes( str_replace("\n", "", $item->post_excerpt) ) ) ),$text_lenght,'...');
						$item_html = '<div class="ajax_search_content"><div class="result_row"><a href="'.$link_detail.'"><span class="rs_avatar">'.$avatar.'</span><div class="rs_content_popup"><span class="rs_name">'.stripslashes( $item->post_title).'</span><span class="rs_description">'.$product_description.'</span></div></a></div></div>';
						$rs_items['page'] .= "$item_html|$link_detail|".stripslashes( $item->post_title)."\n";
						$end_row--;
						if ($end_row < 1) break;
					}
				}
			}
			
			if ( isset($search_in['p_cat']) && $search_in['p_cat'] > 0) {
				$row = $search_in['p_cat'];
				$end_row = $row;
				$number_items = $row+1;
				$inner_extra = '';
				$where = "tt.taxonomy IN ('product_cat') ";
				$where .= $wpdb->prepare( " AND (t.name LIKE %s OR t.name LIKE %s)", like_escape($search_keyword) . '%', '% '.like_escape($search_keyword) . '%');
				if ( trim($wc_predictive_id_excludes['exclude_p_categories']) != '') 
					$where .= " AND t.term_id NOT IN (".trim($wc_predictive_id_excludes['exclude_p_categories']).") ";
				
				if ( $support_wpml )
					$where .= $where_wpml. " AND ic.element_type='tax_product_cat' ";
				
				$orderby = $wpdb->prepare( "t.name NOT LIKE %s ASC, t.name ASC", like_escape($search_keyword) . '%');
				$query = "SELECT t.*, tt.description FROM $wpdb->terms AS t INNER JOIN $wpdb->term_taxonomy AS tt ON t.term_id = tt.term_id {$inner_wpml_table} WHERE {$where} ORDER BY {$orderby} LIMIT 0,$number_items";
																
				$search_cats = $wpdb->get_results($query);
				$total_pcat = count($search_cats);
				if ( $search_cats && $total_pcat > 0 ) {
					$found_items = true;
					$rs_headings['p_cat'] = "<div class='ajax_search_content_title'>". ( function_exists('icl_t') ? icl_t('WooCommerce Predictive Search', 'Product Categories', __('Product Categories', 'woops') ) : __('Product Categories', 'woops') ) ."</div>|#|$search_keyword\n";
					$rs_items['p_cat'] = '';
					foreach ( $search_cats as $item ) {
						$link_detail = get_term_link($item->slug, 'product_cat');
						$avatar = WC_Predictive_Search::woops_get_product_cat_thumbnail($item->term_id,64,64);
						$item_html = '<div class="ajax_search_content"><div class="result_row"><a href="'.$link_detail.'"><span class="rs_avatar">'.$avatar.'</span><div class="rs_content_popup"><span class="rs_name">'.stripslashes( $item->name).'</span><span class="rs_description">'.WC_Predictive_Search::woops_limit_words(strip_tags( str_replace("\n", "", $item->description) ),$text_lenght,'...').'</span></div></a></div></div>';
						$rs_items['p_cat'] .= "$item_html|$link_detail|".stripslashes( $item->name)."\n";
						$end_row--;
						if ($end_row < 1) break;
					}
				}
			}
			
			if ( isset($search_in['p_tag']) && $search_in['p_tag'] > 0) {
				$row = $search_in['p_tag'];
				$end_row = $row;
				$number_items = $row+1;
				$where = "tt.taxonomy IN ('product_tag') ";
				$where .= $wpdb->prepare( " AND (t.name LIKE %s OR t.name LIKE %s)", like_escape($search_keyword) . '%', '% '.like_escape($search_keyword) . '%');
				if ( trim($wc_predictive_id_excludes['exclude_p_tags']) != '') 
					$where .= " AND t.term_id NOT IN (".trim($wc_predictive_id_excludes['exclude_p_tags']).") ";
				
				if ( $support_wpml )
					$where .= $where_wpml. " AND ic.element_type='tax_product_tag' ";
				
				$orderby = $wpdb->prepare( "t.name NOT LIKE %s ASC, t.name ASC", like_escape($search_keyword) . '%');
				$query = "SELECT t.*, tt.description FROM $wpdb->terms AS t INNER JOIN $wpdb->term_taxonomy AS tt ON t.term_id = tt.term_id {$inner_wpml_table} WHERE {$where} ORDER BY {$orderby} LIMIT 0,$number_items";
												
				$search_tags = $wpdb->get_results($query);
				$total_ptag = count($search_tags);	
				if ( $search_tags && $total_ptag > 0 ) {
					$found_items = true;
					$rs_headings['p_tag'] = "<div class='ajax_search_content_title'>". ( function_exists('icl_t') ? icl_t('WooCommerce Predictive Search', 'Product Tags', __('Product Tags', 'woops') ) : __('Product Tags', 'woops') ) ."</div>|#|$search_keyword\n";
					$rs_items['p_tag'] = '';
					foreach ( $search_tags as $item ) {
						$link_detail = get_term_link($item->slug, 'product_tag');
						$avatar = WC_Predictive_Search::woops_get_product_cat_thumbnail($item->term_id,64,64);
						$item_html = '<div class="ajax_search_content"><div class="result_row"><a href="'.$link_detail.'"><span class="rs_avatar">'.$avatar.'</span><div class="rs_content_popup"><span class="rs_name">'.stripslashes( $item->name).'</span><span class="rs_description">'.WC_Predictive_Search::woops_limit_words(strip_tags( str_replace("\n", "", $item->description) ),$text_lenght,'...').'</span></div></a></div></div>';
						$rs_items['p_tag'] .= "$item_html|$link_detail|".stripslashes( $item->name)."\n";
						$end_row--;
						if ($end_row < 1) break;
					}
				}
			}
			
			if ($found_items === false) {
				echo '<div class="ajax_no_result">'. ( function_exists('icl_t') ? icl_t('WooCommerce Predictive Search', 'Keep typing', __('Keep typing...', 'woops') ) : __('Keep typing...', 'woops') ).'</div>';
			} else {
				$rs_footer_html = '';
				foreach ($search_in as $key => $number) {
					if ($number > 0) {
						if (isset($rs_headings[$key]))
							echo $rs_headings[$key];
						if (isset($rs_items[$key]))
							echo $rs_items[$key];
						if (isset($rs_footers[$key]))
							$rs_footer_html .= $rs_footers[$key];
					}
				}
				
				$search_other = $search_list;
				if ($total_product < 1 )  { unset($search_list['product']); unset($search_other['product']); 
				} elseif ($total_product <= $search_in['product']) { unset($search_list['product']); }
				
				if ($total_p_sku < 1) { unset($search_list['p_sku']); unset($search_other['p_sku']);
				} elseif ($total_p_sku <= $search_in['p_sku']) { unset($search_list['p_sku']); }
				
				if ($total_post < 1) { unset($search_list['post']); unset($search_other['post']);
				} elseif ($total_post <= $search_in['post']) { unset($search_list['post']); }
				
				if ($total_page < 1) { unset($search_list['page']); unset($search_other['page']);
				} elseif ($total_page <= $search_in['page']) { unset($search_list['page']); }
				
				if ($total_pcat < 1) { unset($search_list['p_cat']); unset($search_other['p_cat']);
				} elseif ($total_pcat <= $search_in['p_cat']) { unset($search_list['p_cat']); }
				
				if ($total_ptag < 1) { unset($search_list['p_tag']); unset($search_other['p_tag']);
				} elseif ($total_ptag <= $search_in['p_tag']) { unset($search_list['p_tag']); }
				
				if (count($search_list) > 0) {
					$rs_footer_html .= '<div class="more_result" rel="more_result"><span>'. ( function_exists('icl_t') ? icl_t('WooCommerce Predictive Search', 'More result Text', __('See more search results for', 'woops') ) : __('See more search results for', 'woops') ) ." "."'".$search_keyword."' ". ( function_exists('icl_t') ? icl_t('WooCommerce Predictive Search', 'in', __('in', 'woops') ) : __('in', 'woops') ).":</span>";
					foreach ($search_list as $other_rs) {
						if (get_option('permalink_structure') == '')
							$search_in_parameter = '&search_in='.$other_rs;
						else
							$search_in_parameter = '/search-in/'.$other_rs;
						//unset($search_other[$other_rs]);
						if (get_option('permalink_structure') == '')
							$link_search = get_permalink( $woocommerce_search_page_id ).'&rs='.$search_keyword.$search_in_parameter.$extra_parameter_product.$extra_parameter_post.'&search_other='.implode(",", $search_other);
						else
							$link_search = rtrim( get_permalink( $woocommerce_search_page_id ), '/' ).'/keyword/'.$search_keyword.$search_in_parameter.$extra_parameter_product.$extra_parameter_post.'/search-other/'.implode(",", $search_other);
						$rs_item = '<a href="'.$link_search.'">'.$items_search_default[$other_rs]['name'].' <span class="see_more_arrow"></span></a>';
						$rs_footer_html .= "$rs_item";
					}
					$rs_footer_html .= "</div>|#|$search_keyword";
				}
				echo $rs_footer_html;
			}
		}
		die();
	}
	
	/*
	* Include the script for widget search and Search page
	*/
	public static function add_frontend_script() {
		wp_enqueue_script('jquery');
		wp_enqueue_script( 'ajax-woo-autocomplete-script', WOOPS_JS_URL . '/ajax-autocomplete/jquery.autocomplete.js', array(), false, true );
	}
	
	public static function add_frontend_style() {
		wp_enqueue_style( 'ajax-woo-autocomplete-style', WOOPS_JS_URL . '/ajax-autocomplete/jquery.autocomplete.css' );
	}
	
	public static function add_query_vars($aVars) {
		$aVars[] = "keyword";    // represents the name of the product category as shown in the URL
		$aVars[] = "search-in";
		$aVars[] = "pcat";
		$aVars[] = "ptag";
		$aVars[] = "scat";
		$aVars[] = "stag";
		$aVars[] = "search-other";
		return $aVars;
	}
	
	public static function add_rewrite_rules($aRules) {
		//var_dump($_SERVER);
		global $woocommerce_search_page_id;
		//$woocommerce_search_page_id = get_option('woocommerce_search_page_id');
		$search_page = get_page($woocommerce_search_page_id);
		if (!empty($search_page)) {
			$search_page_slug = $search_page->post_name;
			if (stristr($_SERVER['REQUEST_URI'], $search_page_slug) !== FALSE) {
				//$url_text = stristr($_SERVER['REQUEST_URI'], $search_page_slug);
				$position = strpos($_SERVER['REQUEST_URI'], $search_page_slug);
				$new_url = substr($_SERVER['REQUEST_URI'], ($position + strlen($search_page_slug.'/') ) );
				$parameters_array = explode("/", $new_url);
				
				if (is_array($parameters_array) && count($parameters_array) > 1) {
					$array_key = array();
					$array_value = array();
					$number = 0;
					foreach ($parameters_array as $parameter) {
						$number++;
						if (trim($parameter) == '') continue;
						if ($number%2 == 0) $array_value[] = $parameter;
						else $array_key[] = $parameter;
					}
					if (count($array_key) > 0 && count($array_value) > 0 ) {
						$rewrite_rule = '';
						$original_url = '';
						$number_matches = 0;
						foreach ($array_key as $key) {
							$number_matches++;
							$rewrite_rule .= $key.'/([^/]*)/';
							$original_url .= '&'.$key.'=$matches['.$number_matches.']';
						}
						
						//var_dump($search_page_slug.'/'.$rewrite_rule.'?$ => index.php?pagename='.$search_page_slug.$original_url);
						
						//$aNewRules = array($search_page_slug.'/rs/([^/]*)/search_in/([^/]*)/?$' => 'index.php?pagename='.$search_page_slug.'&rs=$matches[1]&search_in=$matches[2]');
						
						$aNewRules = array($search_page_slug.'/'.$rewrite_rule.'?$' => 'index.php?pagename='.$search_page_slug.$original_url);
						$aRules = $aNewRules + $aRules;
						
					}
				}
			}
		}
		return $aRules;
	} 
	
	public static function custom_rewrite_rule() {
		global $woocommerce_search_page_id;
		// BEGIN rewrite
		// hook add_query_vars function into query_vars
		add_filter('query_vars', array('WC_Predictive_Search_Hook_Filter', 'add_query_vars') );
	
		add_filter('rewrite_rules_array', array('WC_Predictive_Search_Hook_Filter', 'add_rewrite_rules') );
		
		//$woocommerce_search_page_id = get_option('woocommerce_search_page_id');
		$search_page = get_page($woocommerce_search_page_id);
		if (!empty($search_page)) {
			$search_page_slug = $search_page->post_name;
			if (stristr($_SERVER['REQUEST_URI'], $search_page_slug) !== FALSE) {
				global $wp_rewrite;
				$wp_rewrite->flush_rules();
			}
		}
		// END rewrite
	}
	
	public static function search_by_title_only( $search, &$wp_query ) {
		global $wpdb;
		$q = $wp_query->query_vars;
		if ( empty( $search) || !isset($q['s']))
			return $search; // skip processing - no search term in query
		$term = esc_sql( like_escape( trim($q['s']) ) );
		$meta_query = array();
		if (isset( $q['meta_query'] ) )
			$meta_query = (array) $q['meta_query'];
			
		//if ($term != '') { var_dump($meta_query); }
		
		$predictive_search_meta = true;
		$where = array();

		$key_only_queries = array();
		$queries = array();
		
		if (is_array($meta_query) && count($meta_query) > 0) {
			$predictive_search_meta = false;
			
			$meta_table = $wpdb->postmeta;
			$relation = $meta_query['relation'];
			if ($relation != 'AND') $relation = 'OR';
			unset($meta_query['relation']);
			
			foreach ($meta_query as $k => $q) {
				if ( $q['key'] == '_predictive_search_focuskw' ) {
					$predictive_search_meta = true;
				}
				
				$meta_key = isset( $q['key'] ) ? trim( $q['key'] ) : '';
				$meta_type = isset( $q['type'] ) ? strtoupper( $q['type'] ) : 'CHAR';
	
				if ( 'NUMERIC' == $meta_type )
					$meta_type = 'SIGNED';
				elseif ( ! in_array( $meta_type, array( 'BINARY', 'CHAR', 'DATE', 'DATETIME', 'DECIMAL', 'SIGNED', 'TIME', 'UNSIGNED' ) ) )
					$meta_type = 'CHAR';
	
				$meta_value = isset( $q['value'] ) ? $q['value'] : null;
	
				if ( isset( $q['compare'] ) )
					$meta_compare = strtoupper( $q['compare'] );
				else
					$meta_compare = is_array( $meta_value ) ? 'IN' : '=';
	
				if ( ! in_array( $meta_compare, array(
					'=', '!=', '>', '>=', '<', '<=',
					'LIKE', 'NOT LIKE',
					'IN', 'NOT IN',
					'BETWEEN', 'NOT BETWEEN',
					'NOT EXISTS'
				) ) )
					$meta_compare = '=';
	
				$alias = $meta_table;
	
				if ( 'NOT EXISTS' == $meta_compare ) {
	
					$where[$k] = ' ' . $alias . '.' . $meta_id_column . ' IS NULL';
	
					continue;
				}
	
	
				$where[$k] = '';
				if ( !empty( $meta_key ) )
					$where[$k] = $wpdb->prepare( "$alias.meta_key = %s", $meta_key );
	
				if ( is_null( $meta_value ) ) {
					continue;
				}
	
				if ( in_array( $meta_compare, array( 'IN', 'NOT IN', 'BETWEEN', 'NOT BETWEEN' ) ) ) {
					if ( ! is_array( $meta_value ) )
						$meta_value = preg_split( '/[,\s]+/', $meta_value );
	
					if ( empty( $meta_value ) ) {
						continue;
					}
				} else {
					$meta_value = trim( $meta_value );
				}
	
				if ( ! empty( $where[$k] ) )
					$where[$k] .= ' AND ';
	
				$where[$k] = ' (' . $where[$k] . $wpdb->prepare( "( CAST($alias.meta_value AS {$meta_type}) LIKE '%s' OR CAST($alias.meta_value AS {$meta_type}) LIKE '%s')  )", like_escape($meta_value).'%', '% '.like_escape($meta_value).'%' );
			}
		}
		
		if ($predictive_search_meta) {
			$where = array_filter( $where );

			if ( empty( $where ) )
				$where = '';
			else
				$where = ' OR (' . implode( "\n{$relation} ", $where ) . ' )';
				
			$search = '';
			if ( isset($q['post_type']) && is_array($q['post_type']) && in_array('product', $q['post_type']) && isset($q['meta_key']) && trim($q['meta_key']) == '_sku' ) $search .= "($wpdb->postmeta.meta_value LIKE '{$term}%' OR $wpdb->postmeta.meta_value LIKE '% {$term}%')";
			elseif ( isset($q['post_type']) && !is_array($q['post_type']) && trim($q['post_type']) == 'product' && isset($q['meta_key']) && trim($q['meta_key']) == '_sku' ) $search .= "($wpdb->postmeta.meta_value LIKE '{$term}%' OR $wpdb->postmeta.meta_value LIKE '% {$term}%')";
			else $search .= "($wpdb->posts.post_title LIKE '{$term}%' OR $wpdb->posts.post_title LIKE '% {$term}%')";
			
			if ( ! empty( $search ) ) {
				$search = " AND ({$search} {$where}) ";
			}
		}
		
		return $search;
	}
	
	public static function predictive_posts_orderby( $orderby, &$wp_query ) {
		global $wpdb;
		$q = $wp_query->query_vars;
		if (isset($q['orderby']) && $q['orderby'] == 'predictive' && isset($q['s']) ) {
			$term = esc_sql( like_escape( trim($q['s']) ) );
			if ( is_array($q['post_type']) && in_array('product', $q['post_type']) && isset($q['meta_key']) && trim($q['meta_key']) == '_sku' )
				$orderby = "$wpdb->postmeta.meta_value NOT LIKE '{$term}%' ASC, $wpdb->postmeta.meta_value ASC";
			elseif ( !is_array($q['post_type']) && trim($q['post_type']) == 'product' && isset($q['meta_key']) && trim($q['meta_key']) == '_sku' ) 
				$orderby = "$wpdb->postmeta.meta_value NOT LIKE '{$term}%' ASC, $wpdb->postmeta.meta_value ASC";
			else
				$orderby = "$wpdb->posts.post_title NOT LIKE '{$term}%' ASC, $wpdb->posts.post_title ASC";
		}
		
		return $orderby;
	}
	
	public static function remove_where_on_focuskw_meta($clauses, $queries, $type, $primary_table, $primary_id_column, $context) {
		$predictive_search_meta = false;
		if ( is_array( $queries) && count($queries) > 0) {
			foreach ($queries as $meta_data) {
				if ( isset($meta_data['key']) && $meta_data['key'] == '_predictive_search_focuskw' ) {
					$predictive_search_meta = true;
					break;
				}
			}
		}
		
		if ($predictive_search_meta) {
			if ( ! $meta_table = _get_meta_table( $type ) ) return $clauses;
			$meta_id_column = esc_sql( $type . '_id' );
			$clauses['where'] = '';
			$clauses['join'] = "LEFT JOIN $meta_table ON $primary_table.$primary_id_column = $meta_table.$meta_id_column";
		}
		return $clauses;
	}
	
	public static function posts_request_unconflict_role_scoper_plugin( $posts_request, &$wp_query ) {
		$posts_request = str_replace('1=2', '2=2', $posts_request);
		
		return $posts_request;
	}
	
	public static function posts_join( $join, &$wp_query ) {
		global $wpdb;
		$q = $wp_query->query_vars;
		$term = esc_sql( like_escape( trim($q['s']) ) );
		if ($term != '') {
			
		}
		
		return $join;
	}
	
	public static function admin_add_scripts(){
		$suffix = defined('SCRIPT_DEBUG') && SCRIPT_DEBUG ? '' : '.min';
		wp_enqueue_script('jquery');
		
		wp_enqueue_style( 'a3rev-chosen-style', WOOPS_JS_URL . '/chosen/chosen.css' );
		wp_enqueue_script( 'chosen', WOOPS_JS_URL . '/chosen/chosen.jquery'.$suffix.'.js', array(), false, true );
		
		wp_enqueue_script( 'a3rev-chosen-script-init', WOOPS_JS_URL.'/init-chosen.js', array(), false, true );
	}
	
	public static function plugin_extra_links($links, $plugin_name) {
		if ( $plugin_name != WOOPS_NAME) {
			return $links;
		}
		$links[] = '<a href="'.WOO_PREDICTIVE_SEARCH_DOCS_URI.'" target="_blank">'.__('Documentation', 'woops').'</a>';
		$links[] = '<a href="https://a3rev.com/forums/forum/woocommerce-plugins/predictive-search/" target="_blank">'.__('Support', 'woops').'</a>';
		return $links;
	}
}
?>